@@ -6,7 +6,7 @@ from framl.config_cli import ConfigFraml
 
 
 class FeatureStore:
-    HOST = "https://feature-store-api-rzhg37iauq-ew.a.run.app"
+    HOST = "https://feature-store-api-rzhg37iauq-ez.a.run.app"
 
     @staticmethod
     def _get_bearer() -> str:
